@@ -1,9 +1,9 @@
 import torch
 import torch.nn as nn
 
-import decoders
-import encoders
 import ops
+from . import decoders
+from . import encoders
 
 
 class Generator(nn.Module):
